@@ -2,7 +2,6 @@
 #define NSTD_STD_GL_H_INCLUDED
 #include "../core/def.h"
 #include "../core/slice.h"
-#include "def.h"
 #include "gui.h"
 #ifdef __cplusplus
 extern "C"
@@ -10,12 +9,13 @@ extern "C"
 #endif
 
 /// Represents a color.
+// Must match https://docs.rs/wgpu/0.12.0/wgpu/struct.Color.html.
 typedef struct
 {
-    double r;
-    double g;
-    double b;
-    double a;
+    NSTDFloat64 r;
+    NSTDFloat64 g;
+    NSTDFloat64 b;
+    NSTDFloat64 a;
 } NSTDGLColor;
 
 /// Represents a graphical surface.
